@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.multifactor.provider.backupString.impl;
 
 import java.security.SecureRandom;
+import com.openexchange.java.CryptoUtil;
 
 /**
  * {@link BackupStringCodeGenerator} generates a random text code used as multifactor "backup-String" recovery
@@ -32,7 +33,6 @@ import java.security.SecureRandom;
 public class BackupStringCodeGenerator {
 
     private static final char[] CHARACTERS = "ABCDEFGHJKLMNPQRSTUVWXYZ0123456789".toCharArray();
-    private static final SecureRandom RANDOM = new SecureRandom();
 
     /**
      * Initializes a new {@link BackupStringCodeGenerator}.
@@ -61,7 +61,7 @@ public class BackupStringCodeGenerator {
 
         char[] chars = new char[length];
         for (int i = length; i-- > 0;) {
-            chars[i] = getChar(RANDOM);
+            chars[i] = getChar(CryptoUtil.getSecureRandom());
         }
         return new String(chars);
     }
