@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@ package com.openexchange.multifactor.provider.sms.token;
 
 import java.security.SecureRandom;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.CryptoUtil;
 import com.openexchange.java.Strings;
 import com.openexchange.multifactor.TokenCreationStrategy;
 
@@ -42,7 +43,7 @@ public class HOTPTokenCreationStrategy implements TokenCreationStrategy {
      */
     public HOTPTokenCreationStrategy() {
         super();
-        random = new SecureRandom();
+        random = CryptoUtil.getSecureRandom();
     }
 
     /**
