@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,10 +24,10 @@ package com.openexchange.multifactor.provider.totp;
 import static com.openexchange.java.Autoboxing.I;
 import java.io.UnsupportedEncodingException;
 import java.net.URLEncoder;
-import java.security.SecureRandom;
 import org.apache.commons.codec.binary.Base32;
 import org.apache.commons.codec.binary.Base64;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.CryptoUtil;
 import com.openexchange.multifactor.MultifactorDevice;
 import com.openexchange.multifactor.MultifactorRequest;
 import com.openexchange.multifactor.exceptions.MultifactorExceptionCodes;
@@ -41,7 +41,6 @@ import com.openexchange.multifactor.exceptions.MultifactorExceptionCodes;
 public class TotpRegister {
 
     private static final String URL= "url";
-    private final SecureRandom random = new SecureRandom();
 
     /**
      * Creates a new, 20 bytes long, random generated String using a cryptographically secure PRNG (SecureRandom).
@@ -50,7 +49,7 @@ public class TotpRegister {
      */
     private String getNewSharedSecret() {
         byte[] newSecret = new byte[20];
-        random.nextBytes(newSecret);
+        CryptoUtil.getSecureRandom().nextBytes(newSecret);
         return new Base32().encodeToString(newSecret);
     }
 
