@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,13 +44,12 @@ public class MultifactorRestActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class[] { MultifactorManagementService.class, UserService.class, ContextService.class };
+        return new Class[] { MultifactorManagementService.class, UserService.class, ContextService.class, Authenticator.class };
     }
 
     @Override
     protected void startBundle() throws Exception {
         logger.info("Starting bundle {}", context.getBundle().getSymbolicName());
-        trackService(Authenticator.class);
         trackService(ConfigurationService.class);
         openTrackers();
         registerService(MultifactorManagementREST.class, new MultifactorManagementREST(this));
