@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -47,7 +47,7 @@ public enum MultifactorProperties implements Property {
      * List of urls that require a recent multifactor authentication. This means that the use must have
      * authenticated within the recentAuthenticationTime.
      */
-    recentAuthRequired("multifactor/device?action=delete, multifactor/device?action=startRegistration"),
+    recentAuthRequired("multifactor/device?action=rename, multifactor/device?action=delete, multifactor/device?action=startRegistration"),
 
     /**
      * The time, in minutes, that a multifactor authentication is considered "recent".
